@@ -177,7 +177,7 @@ methods. Internal methods are usually preceded with a _
 # Let the code begin...
 
 package Bio::SeqIO::genbank;
-$Bio::SeqIO::genbank::VERSION = '1.7.6';
+$Bio::SeqIO::genbank::VERSION = '1.7.7';
 use strict;
 
 use Bio::SeqIO::FTHelper;
@@ -191,9 +191,6 @@ use Bio::Annotation::DBLink;
 
 use base qw(Bio::SeqIO);
 
-# Note that a qualifier that exceeds one line (i.e. a long label) will
-# automatically be quoted regardless:
-
 our $FTQUAL_LINE_LENGTH = 60;
 
 our %FTQUAL_NO_QUOTE = map {$_ => 1} qw(
@@ -1298,18 +1295,27 @@ sub _print_GenBank_FTHelper {
                # There are almost 3x more quoted qualifier values and they
                # are more common too so we take quoted ones first.
                # Long qualifiers, that will be line wrapped, are always quoted
-                elsif (   not $FTQUAL_NO_QUOTE{$tag}
-                       or length("/$tag=$value") >= $FTQUAL_LINE_LENGTH
-                    ) {
-                    my ($pat) = ( $value =~ /\s/ ? '\s|$' : '.|$' );
+
+               # Note (cjf): any tags explicitly *not* quoted must
+               # remain unquoted in all output for proper round trip
+               # parsing:
+               # see https://github.com/bioperl/bioperl-live/issues/321
+
+               # If this breaks *NCBI* examples please file an issue with
+               # example files
+                elsif (   not $FTQUAL_NO_QUOTE{$tag} ) {
+                    my ($pat) = ( $value =~ /\s/ ? '\s|$' :
+                                  '.|$' );
                     $self->_write_line_GenBank_regex
                         ( " " x 21, " " x 21,
                           "/$tag=\"$value\"", $pat, 80 );
                 }
                 else {
+                    my ($pat) = ( $value =~ /[,]/ ? '[,]|$' :
+                                  '.|$' );
                     $self->_write_line_GenBank_regex
                         ( " " x 21, " " x 21,
-                          "/$tag=$value", "\.\|\$", 80 );
+                          "/$tag=$value", $pat, 80 );
                 }
             }
         }
@@ -1836,14 +1842,14 @@ sub _write_line_GenBank {
 sub _write_line_GenBank_regex {
     my ($self, $pre1, $pre2, $line, $regex, $length) = @_;
 
-    #print STDOUT "Going to print with $line!\n";
+    # print STDOUT "Going to print with $line!\n";
 
     $length or $self->throw("Miscalled write_line_GenBank without length. Programming error!");
 
     my $subl  = $length - (length $pre1) - 2;
     my @lines = ();
 
-  CHUNK:
+    CHUNK:
     while ($line) {
         foreach my $pat ($regex, '[,;\.\/-]\s|'.$regex, '[,;\.\/-]|'.$regex) {
             if ($line =~ m/^(.{0,$subl})($pat)(.*)/ ) {
